@@ -6,7 +6,7 @@
 #include <KLocalizedString>
 #include <QObject>
 #include <QTest>
-
+using namespace Qt::Literals::StringLiterals;
 class ImppModelTest : public QObject
 {
     Q_OBJECT
@@ -20,14 +20,14 @@ private Q_SLOTS:
     {
         KContacts::Addressee addressee;
         KContacts::Impp::List impps;
-        impps.append(KContacts::Impp(QUrl{QStringLiteral("matrix:@carl:kde.org")}));
-        impps.append(KContacts::Impp(QUrl{QStringLiteral("matrix:@carl2:kde.org")}));
+        impps.append(KContacts::Impp(QUrl{u"matrix:@carl:kde.org"_s}));
+        impps.append(KContacts::Impp(QUrl{u"matrix:@carl2:kde.org"_s}));
         addressee.setImppList(impps);
         ImppModel imppModel;
         imppModel.loadContact(addressee);
 
         QCOMPARE(imppModel.rowCount(), 2);
-        QCOMPARE(imppModel.data(imppModel.index(1, 0), ImppModel::UrlRole).toString(), QStringLiteral("matrix:@carl2:kde.org"));
+        QCOMPARE(imppModel.data(imppModel.index(1, 0), ImppModel::UrlRole).toString(), u"matrix:@carl2:kde.org"_s);
     }
 };
 
